@@ -70,7 +70,7 @@ class DoxygenRun:
 			for path in Path(src).rglob('*.*'):
 				# # Code from https://stackoverflow.com/a/22058673/15411117
 				# # BUF_SIZE is totally arbitrary, change for your app!
-				BUF_SIZE = 65536  # let's read stuff in 64kb chunks!
+				BUF_SIZE = 65536  # lets read stuff in 64kb chunks!
 				if path.is_file():
 					with open(path, 'rb') as f:
 						while True:
